/*
 * Copyright (c) 2010. Axon Framework
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.axonframework.repository;

/**
 * Exception indicating that the version of a loaded aggregate did not match the given expected version number. This
 * typically means that the aggregate has been modified by another thread between the moment data was queried, and the
 * command modifying the aggregate was handled.
 *
 * @author Allard Buijze
 * @since 0.6
 */
public class ConflictingAggregateVersionException extends ConflictingModificationException {

    private static final long serialVersionUID = 1827438009942802481L;

    /**
     * Initializes the exception using the given <code>message</code>.
     *
     * @param message The message describing the exception
     */
    public ConflictingAggregateVersionException(String message) {
        super(message);
    }

    /**
     * Initializes the exception using the given <code>message</code> and <code>cause</code>.
     *
     * @param message The message describing the exception
     * @param cause   The underlying cause of the exception
     */
    public ConflictingAggregateVersionException(String message, Throwable cause) {
        super(message, cause);
    }
}
